/// <reference types="node" />
import _fs from 'fs';
export interface WriteOptions {
    encoding?: BufferEncoding;
    mode?: string | number | undefined;
    flag?: string | undefined;
}
declare function copy(src: string, dist: string, opts?: {
    /** return true will skip */
    skip?: (file: string, stat: _fs.Stats) => Promise<boolean | void> | boolean | void;
    /** overwrite if exists, default is true */
    overwrite?: boolean;
}): Promise<void>;
export declare type WatchDirHandler = (event: string, filename: string) => void;
export declare type WatchDirOptions = {
    persistent?: boolean;
    /** ms, default 300 */
    threshold?: number;
};
declare function watchDir(dir: string, cb: WatchDirHandler): void;
declare function watchDir(dir: string, options: WatchDirOptions, cb: WatchDirHandler): void;
export declare const fs: {
    watchDir: typeof watchDir;
    copy: typeof copy;
    exists(path: _fs.PathLike): Promise<boolean>;
    /** exists via lstat, if a symbolic link's target file doesn't exists, `fs.exists` will return false, but `fs.lexists` will return true. */
    lexists(path: _fs.PathLike): Promise<boolean>;
    isFile(path: _fs.PathLike): Promise<boolean>;
    isDirectory(path: _fs.PathLike): Promise<boolean>;
    isSymbolicLink(path: _fs.PathLike): Promise<boolean>;
    copyFile: typeof _fs.copyFile.__promisify__ | ((src: _fs.PathLike, dist: _fs.PathLike) => Promise<unknown>);
    /**
     * Make directory with parents, like `mkdir -p`
     * @param dir
     */
    mkdirp(dir: string): Promise<void>;
    /**
     * Make directory with parents, like `mkdir -p`
     * @param dir
     */
    mkdirpSync(dir: string): void;
    /**
     * Remove file or directory recursively, like `rm -rf`
     * @param path The path to remove
     * @param opts Options
     */
    rmrf(path: string): Promise<void>;
    outputFile(path: string, data: any, options?: WriteOptions | undefined): Promise<void>;
    outputFileSync(path: string, data: any, options?: WriteOptions | undefined): void;
    outputJson(path: string, data: object, options?: ({
        space?: number | undefined;
        replacer?: ((key: string, value: any) => any) | undefined;
    } & WriteOptions) | undefined): Promise<void>;
    outputJsonSync(path: string, data: any, options?: ({
        space?: number | undefined;
        replacer?: ((key: string, value: any) => any) | undefined;
    } & WriteOptions) | undefined): void;
    readJson<T = any>(path: string, options?: {
        encoding?: null | undefined;
        flag?: string | undefined;
    } | null | undefined): Promise<T>;
    readJsonSync<T_1 = any>(path: string, options?: {
        encoding?: null | undefined;
        flag?: string | undefined;
    } | null | undefined): T_1;
    iter(dir: string, skip: (path: string, stat: _fs.Stats) => Promise<boolean | void> | boolean | void): Promise<void>;
    access(path: _fs.PathLike, mode?: number | undefined): Promise<void>;
    open(path: _fs.PathLike, flags?: string | number | undefined, mode?: string | number | undefined): Promise<_fs.promises.FileHandle>;
    read<TBuffer extends Uint8Array>(handle: _fs.promises.FileHandle, buffer: TBuffer, offset?: number | null | undefined, length?: number | null | undefined, position?: number | null | undefined): Promise<{
        bytesRead: number;
        buffer: TBuffer;
    }>;
    write<TBuffer_1 extends Uint8Array>(handle: _fs.promises.FileHandle, buffer: TBuffer_1, offset?: number | null | undefined, length?: number | null | undefined, position?: number | null | undefined): Promise<{
        bytesWritten: number;
        buffer: TBuffer_1;
    }>;
    write(handle: _fs.promises.FileHandle, string: string, position?: number | null | undefined, encoding?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | null | undefined): Promise<{
        bytesWritten: number;
        buffer: string;
    }>;
    rename(oldPath: _fs.PathLike, newPath: _fs.PathLike): Promise<void>;
    truncate(path: _fs.PathLike, len?: number | undefined): Promise<void>;
    ftruncate(handle: _fs.promises.FileHandle, len?: number | undefined): Promise<void>;
    rmdir(path: _fs.PathLike, options?: _fs.RmDirOptions | undefined): Promise<void>;
    rm(path: _fs.PathLike, options?: _fs.RmOptions | undefined): Promise<void>;
    fdatasync(handle: _fs.promises.FileHandle): Promise<void>;
    fsync(handle: _fs.promises.FileHandle): Promise<void>;
    mkdir(path: _fs.PathLike, options: _fs.MakeDirectoryOptions & {
        recursive: true;
    }): Promise<string | undefined>;
    mkdir(path: _fs.PathLike, options?: string | number | (_fs.MakeDirectoryOptions & {
        recursive?: false | undefined;
    }) | null | undefined): Promise<void>;
    mkdir(path: _fs.PathLike, options?: string | number | _fs.MakeDirectoryOptions | null | undefined): Promise<string | undefined>;
    readdir(path: _fs.PathLike, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | (_fs.BaseEncodingOptions & {
        withFileTypes?: false | undefined;
    }) | null | undefined): Promise<string[]>;
    readdir(path: _fs.PathLike, options: "buffer" | {
        encoding: "buffer";
        withFileTypes?: false | undefined;
    }): Promise<Buffer[]>;
    readdir(path: _fs.PathLike, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | (_fs.BaseEncodingOptions & {
        withFileTypes?: false | undefined;
    }) | null | undefined): Promise<string[] | Buffer[]>;
    readdir(path: _fs.PathLike, options: _fs.BaseEncodingOptions & {
        withFileTypes: true;
    }): Promise<_fs.Dirent[]>;
    readlink(path: _fs.PathLike, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | _fs.BaseEncodingOptions | null | undefined): Promise<string>;
    readlink(path: _fs.PathLike, options: _fs.BufferEncodingOption): Promise<Buffer>;
    readlink(path: _fs.PathLike, options?: string | _fs.BaseEncodingOptions | null | undefined): Promise<string | Buffer>;
    symlink(target: _fs.PathLike, path: _fs.PathLike, type?: string | null | undefined): Promise<void>;
    lstat(path: _fs.PathLike, opts?: (_fs.StatOptions & {
        bigint?: false | undefined;
    }) | undefined): Promise<_fs.Stats>;
    lstat(path: _fs.PathLike, opts: _fs.StatOptions & {
        bigint: true;
    }): Promise<_fs.BigIntStats>;
    lstat(path: _fs.PathLike, opts?: _fs.StatOptions | undefined): Promise<_fs.Stats | _fs.BigIntStats>;
    stat(path: _fs.PathLike, opts?: (_fs.StatOptions & {
        bigint?: false | undefined;
    }) | undefined): Promise<_fs.Stats>;
    stat(path: _fs.PathLike, opts: _fs.StatOptions & {
        bigint: true;
    }): Promise<_fs.BigIntStats>;
    stat(path: _fs.PathLike, opts?: _fs.StatOptions | undefined): Promise<_fs.Stats | _fs.BigIntStats>;
    link(existingPath: _fs.PathLike, newPath: _fs.PathLike): Promise<void>;
    unlink(path: _fs.PathLike): Promise<void>;
    fchmod(handle: _fs.promises.FileHandle, mode: string | number): Promise<void>;
    chmod(path: _fs.PathLike, mode: string | number): Promise<void>;
    lchmod(path: _fs.PathLike, mode: string | number): Promise<void>;
    lchown(path: _fs.PathLike, uid: number, gid: number): Promise<void>;
    lutimes(path: _fs.PathLike, atime: string | number | Date, mtime: string | number | Date): Promise<void>;
    fchown(handle: _fs.promises.FileHandle, uid: number, gid: number): Promise<void>;
    chown(path: _fs.PathLike, uid: number, gid: number): Promise<void>;
    utimes(path: _fs.PathLike, atime: string | number | Date, mtime: string | number | Date): Promise<void>;
    futimes(handle: _fs.promises.FileHandle, atime: string | number | Date, mtime: string | number | Date): Promise<void>;
    realpath(path: _fs.PathLike, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | _fs.BaseEncodingOptions | null | undefined): Promise<string>;
    realpath(path: _fs.PathLike, options: _fs.BufferEncodingOption): Promise<Buffer>;
    realpath(path: _fs.PathLike, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | _fs.BaseEncodingOptions | null | undefined): Promise<string | Buffer>;
    mkdtemp(prefix: string, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | _fs.BaseEncodingOptions | null | undefined): Promise<string>;
    mkdtemp(prefix: string, options: _fs.BufferEncodingOption): Promise<Buffer>;
    mkdtemp(prefix: string, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | _fs.BaseEncodingOptions | null | undefined): Promise<string | Buffer>;
    writeFile(path: string | Buffer | import("url").URL | _fs.promises.FileHandle, data: string | Uint8Array, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | (_fs.BaseEncodingOptions & {
        mode?: string | number | undefined;
        flag?: string | number | undefined;
    }) | null | undefined): Promise<void>;
    appendFile(path: string | Buffer | import("url").URL | _fs.promises.FileHandle, data: string | Uint8Array, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | (_fs.BaseEncodingOptions & {
        mode?: string | number | undefined;
        flag?: string | number | undefined;
    }) | null | undefined): Promise<void>;
    readFile(path: string | Buffer | import("url").URL | _fs.promises.FileHandle, options?: {
        encoding?: null | undefined;
        flag?: string | number | undefined;
    } | null | undefined): Promise<Buffer>;
    readFile(path: string | Buffer | import("url").URL | _fs.promises.FileHandle, options: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | {
        encoding: BufferEncoding;
        flag?: string | number | undefined;
    }): Promise<string>;
    readFile(path: string | Buffer | import("url").URL | _fs.promises.FileHandle, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | (_fs.BaseEncodingOptions & {
        flag?: string | number | undefined;
    }) | null | undefined): Promise<string | Buffer>;
    opendir(path: _fs.PathLike, options?: _fs.OpenDirOptions | undefined): Promise<_fs.Dir>;
    constants: typeof _fs.constants;
    renameSync(oldPath: _fs.PathLike, newPath: _fs.PathLike): void;
    truncateSync(path: _fs.PathLike, len?: number | null | undefined): void;
    ftruncateSync(fd: number, len?: number | null | undefined): void;
    chownSync(path: _fs.PathLike, uid: number, gid: number): void;
    fchownSync(fd: number, uid: number, gid: number): void;
    lchownSync(path: _fs.PathLike, uid: number, gid: number): void;
    lutimesSync(path: _fs.PathLike, atime: string | number | Date, mtime: string | number | Date): void;
    chmodSync(path: _fs.PathLike, mode: string | number): void;
    fchmodSync(fd: number, mode: string | number): void;
    lchmodSync(path: _fs.PathLike, mode: string | number): void;
    statSync(path: _fs.PathLike, options?: (_fs.StatOptions & {
        bigint?: false | undefined;
    }) | undefined): _fs.Stats;
    statSync(path: _fs.PathLike, options: _fs.StatOptions & {
        bigint: true;
    }): _fs.BigIntStats;
    statSync(path: _fs.PathLike, options?: _fs.StatOptions | undefined): _fs.Stats | _fs.BigIntStats;
    fstat: typeof _fs.fstat;
    fstatSync(fd: number, options?: (_fs.StatOptions & {
        bigint?: false | undefined;
    }) | undefined): _fs.Stats;
    fstatSync(fd: number, options: _fs.StatOptions & {
        bigint: true;
    }): _fs.BigIntStats;
    fstatSync(fd: number, options?: _fs.StatOptions | undefined): _fs.Stats | _fs.BigIntStats;
    lstatSync(path: _fs.PathLike, options?: (_fs.StatOptions & {
        bigint?: false | undefined;
    }) | undefined): _fs.Stats;
    lstatSync(path: _fs.PathLike, options: _fs.StatOptions & {
        bigint: true;
    }): _fs.BigIntStats;
    lstatSync(path: _fs.PathLike, options?: _fs.StatOptions | undefined): _fs.Stats | _fs.BigIntStats;
    linkSync(existingPath: _fs.PathLike, newPath: _fs.PathLike): void;
    symlinkSync(target: _fs.PathLike, path: _fs.PathLike, type?: "dir" | "file" | "junction" | null | undefined): void;
    readlinkSync(path: _fs.PathLike, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | _fs.BaseEncodingOptions | null | undefined): string;
    readlinkSync(path: _fs.PathLike, options: _fs.BufferEncodingOption): Buffer;
    readlinkSync(path: _fs.PathLike, options?: string | _fs.BaseEncodingOptions | null | undefined): string | Buffer;
    realpathSync: typeof _fs.realpathSync;
    unlinkSync(path: _fs.PathLike): void;
    rmdirSync(path: _fs.PathLike, options?: _fs.RmDirOptions | undefined): void;
    rmSync(path: _fs.PathLike, options?: _fs.RmOptions | undefined): void;
    mkdirSync(path: _fs.PathLike, options: _fs.MakeDirectoryOptions & {
        recursive: true;
    }): string | undefined;
    mkdirSync(path: _fs.PathLike, options?: string | number | (_fs.MakeDirectoryOptions & {
        recursive?: false | undefined;
    }) | null | undefined): void;
    mkdirSync(path: _fs.PathLike, options?: string | number | _fs.MakeDirectoryOptions | null | undefined): string | undefined;
    mkdtempSync(prefix: string, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | _fs.BaseEncodingOptions | null | undefined): string;
    mkdtempSync(prefix: string, options: _fs.BufferEncodingOption): Buffer;
    mkdtempSync(prefix: string, options?: string | _fs.BaseEncodingOptions | null | undefined): string | Buffer;
    readdirSync(path: _fs.PathLike, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | {
        encoding: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | null;
        withFileTypes?: false | undefined;
    } | null | undefined): string[];
    readdirSync(path: _fs.PathLike, options: "buffer" | {
        encoding: "buffer";
        withFileTypes?: false | undefined;
    }): Buffer[];
    readdirSync(path: _fs.PathLike, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | (_fs.BaseEncodingOptions & {
        withFileTypes?: false | undefined;
    }) | null | undefined): string[] | Buffer[];
    readdirSync(path: _fs.PathLike, options: _fs.BaseEncodingOptions & {
        withFileTypes: true;
    }): _fs.Dirent[];
    close: typeof _fs.close;
    closeSync(fd: number): void;
    openSync(path: _fs.PathLike, flags: string | number, mode?: string | number | null | undefined): number;
    utimesSync(path: _fs.PathLike, atime: string | number | Date, mtime: string | number | Date): void;
    futimesSync(fd: number, atime: string | number | Date, mtime: string | number | Date): void;
    fsyncSync(fd: number): void;
    writeSync(fd: number, buffer: NodeJS.ArrayBufferView, offset?: number | null | undefined, length?: number | null | undefined, position?: number | null | undefined): number;
    writeSync(fd: number, string: string, position?: number | null | undefined, encoding?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | null | undefined): number;
    readSync(fd: number, buffer: NodeJS.ArrayBufferView, offset: number, length: number, position: number | null): number;
    readSync(fd: number, buffer: NodeJS.ArrayBufferView, opts?: _fs.ReadSyncOptions | undefined): number;
    readFileSync(path: string | number | Buffer | import("url").URL, options?: {
        encoding?: null | undefined;
        flag?: string | undefined;
    } | null | undefined): Buffer;
    readFileSync(path: string | number | Buffer | import("url").URL, options: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | {
        encoding: BufferEncoding;
        flag?: string | undefined;
    }): string;
    readFileSync(path: string | number | Buffer | import("url").URL, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | (_fs.BaseEncodingOptions & {
        flag?: string | undefined;
    }) | null | undefined): string | Buffer;
    writeFileSync(path: string | number | Buffer | import("url").URL, data: import("crypto").BinaryLike, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | (_fs.BaseEncodingOptions & {
        mode?: string | number | undefined;
        flag?: string | undefined;
    }) | null | undefined): void;
    appendFileSync(file: string | number | Buffer | import("url").URL, data: string | Uint8Array, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | (_fs.BaseEncodingOptions & {
        mode?: string | number | undefined;
        flag?: string | undefined;
    }) | null | undefined): void;
    watchFile(filename: _fs.PathLike, options: {
        persistent?: boolean | undefined;
        interval?: number | undefined;
    } | undefined, listener: (curr: _fs.Stats, prev: _fs.Stats) => void): void;
    watchFile(filename: _fs.PathLike, listener: (curr: _fs.Stats, prev: _fs.Stats) => void): void;
    unwatchFile(filename: _fs.PathLike, listener?: ((curr: _fs.Stats, prev: _fs.Stats) => void) | undefined): void;
    watch(filename: _fs.PathLike, options: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | {
        encoding?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | null | undefined;
        persistent?: boolean | undefined;
        recursive?: boolean | undefined;
    } | null | undefined, listener?: ((event: "change" | "rename", filename: string) => void) | undefined): _fs.FSWatcher;
    watch(filename: _fs.PathLike, options: "buffer" | {
        encoding: "buffer";
        persistent?: boolean | undefined;
        recursive?: boolean | undefined;
    }, listener?: ((event: "change" | "rename", filename: Buffer) => void) | undefined): _fs.FSWatcher;
    watch(filename: _fs.PathLike, options: string | {
        encoding?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | null | undefined;
        persistent?: boolean | undefined;
        recursive?: boolean | undefined;
    } | null, listener?: ((event: "change" | "rename", filename: string | Buffer) => void) | undefined): _fs.FSWatcher;
    watch(filename: _fs.PathLike, listener?: ((event: "change" | "rename", filename: string) => any) | undefined): _fs.FSWatcher;
    existsSync(path: _fs.PathLike): boolean;
    accessSync(path: _fs.PathLike, mode?: number | undefined): void;
    createReadStream(path: _fs.PathLike, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | {
        flags?: string | undefined;
        encoding?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | undefined;
        fd?: number | undefined;
        mode?: number | undefined;
        autoClose?: boolean | undefined;
        emitClose?: boolean | undefined;
        start?: number | undefined;
        end?: number | undefined;
        highWaterMark?: number | undefined;
    } | undefined): _fs.ReadStream;
    createWriteStream(path: _fs.PathLike, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | {
        flags?: string | undefined;
        encoding?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | undefined;
        fd?: number | undefined;
        mode?: number | undefined;
        autoClose?: boolean | undefined;
        emitClose?: boolean | undefined;
        start?: number | undefined;
        highWaterMark?: number | undefined;
    } | undefined): _fs.WriteStream;
    fdatasyncSync(fd: number): void;
    copyFileSync(src: _fs.PathLike, dest: _fs.PathLike, flags?: number | undefined): void;
    writev: typeof _fs.writev;
    writevSync(fd: number, buffers: readonly NodeJS.ArrayBufferView[], position?: number | undefined): number;
    readv: typeof _fs.readv;
    readvSync(fd: number, buffers: readonly NodeJS.ArrayBufferView[], position?: number | undefined): number;
    opendirSync(path: _fs.PathLike, options?: _fs.OpenDirOptions | undefined): _fs.Dir;
    promises: typeof _fs.promises;
    Stats: typeof _fs.Stats;
    Dirent: typeof _fs.Dirent;
    Dir: typeof _fs.Dir;
    ReadStream: typeof _fs.ReadStream;
    WriteStream: typeof _fs.WriteStream;
    BigIntStats: typeof _fs.BigIntStats;
};
export {};
