/// <reference types="node" />
import { Task } from './task';
import { ShellContext } from './exec';
import { ILoggerProps, Logger } from './logger';
export interface GlobalOptions {
    /**
     * @default true
     */
    loading?: boolean;
    indent?: number;
    /**
     * @description Whether task options only allow defined options, default false
     * @default false
     */
    strict?: boolean;
    logger?: ILoggerProps;
    logCommand?: boolean;
    options?: any;
    rawArgs?: string[];
    /** @default true */
    showTaskDuration?: boolean;
}
export interface RunDepOptions {
    rawArgs?: string[];
    parentCtx?: TaskContext | null;
    /** default is false */
    loading?: boolean;
    indent?: number;
}
export interface RunTaskOptions extends RunDepOptions {
    options?: any;
    rawArgs?: string[];
    parentCtx?: TaskContext | null;
    force?: boolean;
}
export declare enum TaskState {
    waiting = "waiting",
    pending = "pending",
    skipped = "skipped",
    loading = "loading",
    succeeded = "succeeded",
    failed = "failed"
}
export interface DepsTree {
    uid: string;
    task: Task;
    asyncDeps: DepsTree[][];
    syncDeps: DepsTree[];
    state: TaskState;
    depth: number;
    priority: number;
    duration: number;
}
export declare class TaskContext<O = any> extends ShellContext {
    task: Task<O>;
    global: GlobalOptions;
    fs: {
        watchDir: {
            (dir: string, cb: import("./fs").WatchDirHandler): void;
            (dir: string, options: import("./fs").WatchDirOptions, cb: import("./fs").WatchDirHandler): void;
        };
        copy: (src: string, dist: string, opts?: {
            skip?: ((file: string, stat: import("fs").Stats) => boolean | void | Promise<boolean | void>) | undefined;
            overwrite?: boolean | undefined;
        } | undefined) => Promise<void>;
        exists(path: import("fs").PathLike): Promise<boolean>;
        lexists(path: import("fs").PathLike): Promise<boolean>;
        isFile(path: import("fs").PathLike): Promise<boolean>;
        isDirectory(path: import("fs").PathLike): Promise<boolean>;
        isSymbolicLink(path: import("fs").PathLike): Promise<boolean>;
        copyFile: typeof import("fs").copyFile.__promisify__ | ((src: import("fs").PathLike, dist: import("fs").PathLike) => Promise<unknown>);
        mkdirp(dir: string): Promise<void>;
        mkdirpSync(dir: string): void;
        rmrf(path: string): Promise<void>;
        outputFile(path: string, data: any, options?: import("./fs").WriteOptions | undefined): Promise<void>;
        outputFileSync(path: string, data: any, options?: import("./fs").WriteOptions | undefined): void;
        outputJson(path: string, data: object, options?: ({
            space?: number | undefined;
            replacer?: ((key: string, value: any) => any) | undefined;
        } & import("./fs").WriteOptions) | undefined): Promise<void>;
        outputJsonSync(path: string, data: any, options?: ({
            space?: number | undefined;
            replacer?: ((key: string, value: any) => any) | undefined;
        } & import("./fs").WriteOptions) | undefined): void;
        readJson<T = any>(path: string, options?: {
            encoding?: null | undefined;
            flag?: string | undefined;
        } | null | undefined): Promise<T>;
        readJsonSync<T_1 = any>(path: string, options?: {
            encoding?: null | undefined;
            flag?: string | undefined;
        } | null | undefined): T_1;
        iter(dir: string, skip: (path: string, stat: import("fs").Stats) => boolean | void | Promise<boolean | void>): Promise<void>;
        access(path: import("fs").PathLike, mode?: number | undefined): Promise<void>;
        open(path: import("fs").PathLike, flags?: string | number | undefined, mode?: string | number | undefined): Promise<import("fs/promises").FileHandle>;
        read<TBuffer extends Uint8Array>(handle: import("fs/promises").FileHandle, buffer: TBuffer, offset?: number | null | undefined, length?: number | null | undefined, position?: number | null | undefined): Promise<{
            bytesRead: number;
            buffer: TBuffer;
        }>;
        write<TBuffer_1 extends Uint8Array>(handle: import("fs/promises").FileHandle, buffer: TBuffer_1, offset?: number | null | undefined, length?: number | null | undefined, position?: number | null | undefined): Promise<{
            bytesWritten: number;
            buffer: TBuffer_1;
        }>;
        write(handle: import("fs/promises").FileHandle, string: string, position?: number | null | undefined, encoding?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | null | undefined): Promise<{
            bytesWritten: number;
            buffer: string;
        }>;
        rename(oldPath: import("fs").PathLike, newPath: import("fs").PathLike): Promise<void>;
        truncate(path: import("fs").PathLike, len?: number | undefined): Promise<void>;
        ftruncate(handle: import("fs/promises").FileHandle, len?: number | undefined): Promise<void>;
        rmdir(path: import("fs").PathLike, options?: import("fs").RmDirOptions | undefined): Promise<void>;
        rm(path: import("fs").PathLike, options?: import("fs").RmOptions | undefined): Promise<void>;
        fdatasync(handle: import("fs/promises").FileHandle): Promise<void>;
        fsync(handle: import("fs/promises").FileHandle): Promise<void>;
        mkdir(path: import("fs").PathLike, options: import("fs").MakeDirectoryOptions & {
            recursive: true;
        }): Promise<string | undefined>;
        mkdir(path: import("fs").PathLike, options?: string | number | (import("fs").MakeDirectoryOptions & {
            recursive?: false | undefined;
        }) | null | undefined): Promise<void>;
        mkdir(path: import("fs").PathLike, options?: string | number | import("fs").MakeDirectoryOptions | null | undefined): Promise<string | undefined>;
        readdir(path: import("fs").PathLike, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | (import("fs").BaseEncodingOptions & {
            withFileTypes?: false | undefined;
        }) | null | undefined): Promise<string[]>;
        readdir(path: import("fs").PathLike, options: "buffer" | {
            encoding: "buffer";
            withFileTypes?: false | undefined;
        }): Promise<Buffer[]>;
        readdir(path: import("fs").PathLike, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | (import("fs").BaseEncodingOptions & {
            withFileTypes?: false | undefined;
        }) | null | undefined): Promise<string[] | Buffer[]>;
        readdir(path: import("fs").PathLike, options: import("fs").BaseEncodingOptions & {
            withFileTypes: true;
        }): Promise<import("fs").Dirent[]>;
        readlink(path: import("fs").PathLike, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | import("fs").BaseEncodingOptions | null | undefined): Promise<string>;
        readlink(path: import("fs").PathLike, options: import("fs").BufferEncodingOption): Promise<Buffer>;
        readlink(path: import("fs").PathLike, options?: string | import("fs").BaseEncodingOptions | null | undefined): Promise<string | Buffer>;
        symlink(target: import("fs").PathLike, path: import("fs").PathLike, type?: string | null | undefined): Promise<void>;
        lstat(path: import("fs").PathLike, opts?: (import("fs").StatOptions & {
            bigint?: false | undefined;
        }) | undefined): Promise<import("fs").Stats>;
        lstat(path: import("fs").PathLike, opts: import("fs").StatOptions & {
            bigint: true;
        }): Promise<import("fs").BigIntStats>;
        lstat(path: import("fs").PathLike, opts?: import("fs").StatOptions | undefined): Promise<import("fs").Stats | import("fs").BigIntStats>;
        stat(path: import("fs").PathLike, opts?: (import("fs").StatOptions & {
            bigint?: false | undefined;
        }) | undefined): Promise<import("fs").Stats>;
        stat(path: import("fs").PathLike, opts: import("fs").StatOptions & {
            bigint: true;
        }): Promise<import("fs").BigIntStats>;
        stat(path: import("fs").PathLike, opts?: import("fs").StatOptions | undefined): Promise<import("fs").Stats | import("fs").BigIntStats>;
        link(existingPath: import("fs").PathLike, newPath: import("fs").PathLike): Promise<void>;
        unlink(path: import("fs").PathLike): Promise<void>;
        fchmod(handle: import("fs/promises").FileHandle, mode: string | number): Promise<void>;
        chmod(path: import("fs").PathLike, mode: string | number): Promise<void>;
        lchmod(path: import("fs").PathLike, mode: string | number): Promise<void>;
        lchown(path: import("fs").PathLike, uid: number, gid: number): Promise<void>;
        lutimes(path: import("fs").PathLike, atime: string | number | Date, mtime: string | number | Date): Promise<void>;
        fchown(handle: import("fs/promises").FileHandle, uid: number, gid: number): Promise<void>;
        chown(path: import("fs").PathLike, uid: number, gid: number): Promise<void>;
        utimes(path: import("fs").PathLike, atime: string | number | Date, mtime: string | number | Date): Promise<void>;
        futimes(handle: import("fs/promises").FileHandle, atime: string | number | Date, mtime: string | number | Date): Promise<void>;
        realpath(path: import("fs").PathLike, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | import("fs").BaseEncodingOptions | null | undefined): Promise<string>;
        realpath(path: import("fs").PathLike, options: import("fs").BufferEncodingOption): Promise<Buffer>;
        realpath(path: import("fs").PathLike, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | import("fs").BaseEncodingOptions | null | undefined): Promise<string | Buffer>;
        mkdtemp(prefix: string, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | import("fs").BaseEncodingOptions | null | undefined): Promise<string>;
        mkdtemp(prefix: string, options: import("fs").BufferEncodingOption): Promise<Buffer>;
        mkdtemp(prefix: string, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | import("fs").BaseEncodingOptions | null | undefined): Promise<string | Buffer>;
        writeFile(path: string | Buffer | import("url").URL | import("fs/promises").FileHandle, data: string | Uint8Array, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | (import("fs").BaseEncodingOptions & {
            mode?: string | number | undefined;
            flag?: string | number | undefined;
        }) | null | undefined): Promise<void>;
        appendFile(path: string | Buffer | import("url").URL | import("fs/promises").FileHandle, data: string | Uint8Array, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | (import("fs").BaseEncodingOptions & {
            mode?: string | number | undefined;
            flag?: string | number | undefined;
        }) | null | undefined): Promise<void>;
        readFile(path: string | Buffer | import("url").URL | import("fs/promises").FileHandle, options?: {
            encoding?: null | undefined;
            flag?: string | number | undefined;
        } | null | undefined): Promise<Buffer>;
        readFile(path: string | Buffer | import("url").URL | import("fs/promises").FileHandle, options: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | {
            encoding: BufferEncoding;
            flag?: string | number | undefined;
        }): Promise<string>;
        readFile(path: string | Buffer | import("url").URL | import("fs/promises").FileHandle, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | (import("fs").BaseEncodingOptions & {
            flag?: string | number | undefined;
        }) | null | undefined): Promise<string | Buffer>;
        opendir(path: import("fs").PathLike, options?: import("fs").OpenDirOptions | undefined): Promise<import("fs").Dir>;
        constants: typeof import("fs").constants;
        renameSync(oldPath: import("fs").PathLike, newPath: import("fs").PathLike): void;
        truncateSync(path: import("fs").PathLike, len?: number | null | undefined): void;
        ftruncateSync(fd: number, len?: number | null | undefined): void;
        chownSync(path: import("fs").PathLike, uid: number, gid: number): void;
        fchownSync(fd: number, uid: number, gid: number): void;
        lchownSync(path: import("fs").PathLike, uid: number, gid: number): void;
        lutimesSync(path: import("fs").PathLike, atime: string | number | Date, mtime: string | number | Date): void;
        chmodSync(path: import("fs").PathLike, mode: string | number): void;
        fchmodSync(fd: number, mode: string | number): void;
        lchmodSync(path: import("fs").PathLike, mode: string | number): void;
        statSync(path: import("fs").PathLike, options?: (import("fs").StatOptions & {
            bigint?: false | undefined;
        }) | undefined): import("fs").Stats;
        statSync(path: import("fs").PathLike, options: import("fs").StatOptions & {
            bigint: true;
        }): import("fs").BigIntStats;
        statSync(path: import("fs").PathLike, options?: import("fs").StatOptions | undefined): import("fs").Stats | import("fs").BigIntStats;
        fstat: typeof import("fs").fstat;
        fstatSync(fd: number, options?: (import("fs").StatOptions & {
            bigint?: false | undefined;
        }) | undefined): import("fs").Stats;
        fstatSync(fd: number, options: import("fs").StatOptions & {
            bigint: true;
        }): import("fs").BigIntStats;
        fstatSync(fd: number, options?: import("fs").StatOptions | undefined): import("fs").Stats | import("fs").BigIntStats;
        lstatSync(path: import("fs").PathLike, options?: (import("fs").StatOptions & {
            bigint?: false | undefined;
        }) | undefined): import("fs").Stats;
        lstatSync(path: import("fs").PathLike, options: import("fs").StatOptions & {
            bigint: true;
        }): import("fs").BigIntStats;
        lstatSync(path: import("fs").PathLike, options?: import("fs").StatOptions | undefined): import("fs").Stats | import("fs").BigIntStats;
        linkSync(existingPath: import("fs").PathLike, newPath: import("fs").PathLike): void;
        symlinkSync(target: import("fs").PathLike, path: import("fs").PathLike, type?: "dir" | "file" | "junction" | null | undefined): void;
        readlinkSync(path: import("fs").PathLike, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | import("fs").BaseEncodingOptions | null | undefined): string;
        readlinkSync(path: import("fs").PathLike, options: import("fs").BufferEncodingOption): Buffer;
        readlinkSync(path: import("fs").PathLike, options?: string | import("fs").BaseEncodingOptions | null | undefined): string | Buffer;
        realpathSync: typeof import("fs").realpathSync;
        unlinkSync(path: import("fs").PathLike): void;
        rmdirSync(path: import("fs").PathLike, options?: import("fs").RmDirOptions | undefined): void;
        rmSync(path: import("fs").PathLike, options?: import("fs").RmOptions | undefined): void;
        mkdirSync(path: import("fs").PathLike, options: import("fs").MakeDirectoryOptions & {
            recursive: true;
        }): string | undefined;
        mkdirSync(path: import("fs").PathLike, options?: string | number | (import("fs").MakeDirectoryOptions & {
            recursive?: false | undefined;
        }) | null | undefined): void;
        mkdirSync(path: import("fs").PathLike, options?: string | number | import("fs").MakeDirectoryOptions | null | undefined): string | undefined;
        mkdtempSync(prefix: string, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | import("fs").BaseEncodingOptions | null | undefined): string;
        mkdtempSync(prefix: string, options: import("fs").BufferEncodingOption): Buffer;
        mkdtempSync(prefix: string, options?: string | import("fs").BaseEncodingOptions | null | undefined): string | Buffer;
        readdirSync(path: import("fs").PathLike, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | {
            encoding: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | null;
            withFileTypes?: false | undefined;
        } | null | undefined): string[];
        readdirSync(path: import("fs").PathLike, options: "buffer" | {
            encoding: "buffer";
            withFileTypes?: false | undefined;
        }): Buffer[];
        readdirSync(path: import("fs").PathLike, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | (import("fs").BaseEncodingOptions & {
            withFileTypes?: false | undefined;
        }) | null | undefined): string[] | Buffer[];
        readdirSync(path: import("fs").PathLike, options: import("fs").BaseEncodingOptions & {
            withFileTypes: true;
        }): import("fs").Dirent[];
        close: typeof import("fs").close;
        closeSync(fd: number): void;
        openSync(path: import("fs").PathLike, flags: string | number, mode?: string | number | null | undefined): number;
        utimesSync(path: import("fs").PathLike, atime: string | number | Date, mtime: string | number | Date): void;
        futimesSync(fd: number, atime: string | number | Date, mtime: string | number | Date): void;
        fsyncSync(fd: number): void;
        writeSync(fd: number, buffer: NodeJS.ArrayBufferView, offset?: number | null | undefined, length?: number | null | undefined, position?: number | null | undefined): number;
        writeSync(fd: number, string: string, position?: number | null | undefined, encoding?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | null | undefined): number;
        readSync(fd: number, buffer: NodeJS.ArrayBufferView, offset: number, length: number, position: number | null): number;
        readSync(fd: number, buffer: NodeJS.ArrayBufferView, opts?: import("fs").ReadSyncOptions | undefined): number;
        readFileSync(path: string | number | Buffer | import("url").URL, options?: {
            encoding?: null | undefined;
            flag?: string | undefined;
        } | null | undefined): Buffer;
        readFileSync(path: string | number | Buffer | import("url").URL, options: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | {
            encoding: BufferEncoding;
            flag?: string | undefined;
        }): string;
        readFileSync(path: string | number | Buffer | import("url").URL, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | (import("fs").BaseEncodingOptions & {
            flag?: string | undefined;
        }) | null | undefined): string | Buffer;
        writeFileSync(path: string | number | Buffer | import("url").URL, data: import("crypto").BinaryLike, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | (import("fs").BaseEncodingOptions & {
            mode?: string | number | undefined;
            flag?: string | undefined;
        }) | null | undefined): void;
        appendFileSync(file: string | number | Buffer | import("url").URL, data: string | Uint8Array, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | (import("fs").BaseEncodingOptions & {
            mode?: string | number | undefined;
            flag?: string | undefined;
        }) | null | undefined): void;
        watchFile(filename: import("fs").PathLike, options: {
            persistent?: boolean | undefined;
            interval?: number | undefined;
        } | undefined, listener: (curr: import("fs").Stats, prev: import("fs").Stats) => void): void;
        watchFile(filename: import("fs").PathLike, listener: (curr: import("fs").Stats, prev: import("fs").Stats) => void): void;
        unwatchFile(filename: import("fs").PathLike, listener?: ((curr: import("fs").Stats, prev: import("fs").Stats) => void) | undefined): void;
        watch(filename: import("fs").PathLike, options: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | {
            encoding?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | null | undefined;
            persistent?: boolean | undefined;
            recursive?: boolean | undefined;
        } | null | undefined, listener?: ((event: "change" | "rename", filename: string) => void) | undefined): import("fs").FSWatcher;
        watch(filename: import("fs").PathLike, options: "buffer" | {
            encoding: "buffer";
            persistent?: boolean | undefined;
            recursive?: boolean | undefined;
        }, listener?: ((event: "change" | "rename", filename: Buffer) => void) | undefined): import("fs").FSWatcher;
        watch(filename: import("fs").PathLike, options: string | {
            encoding?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | null | undefined;
            persistent?: boolean | undefined;
            recursive?: boolean | undefined;
        } | null, listener?: ((event: "change" | "rename", filename: string | Buffer) => void) | undefined): import("fs").FSWatcher;
        watch(filename: import("fs").PathLike, listener?: ((event: "change" | "rename", filename: string) => any) | undefined): import("fs").FSWatcher;
        existsSync(path: import("fs").PathLike): boolean;
        accessSync(path: import("fs").PathLike, mode?: number | undefined): void;
        createReadStream(path: import("fs").PathLike, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | {
            flags?: string | undefined;
            encoding?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | undefined;
            fd?: number | undefined;
            mode?: number | undefined;
            autoClose?: boolean | undefined;
            emitClose?: boolean | undefined;
            start?: number | undefined;
            end?: number | undefined;
            highWaterMark?: number | undefined;
        } | undefined): import("fs").ReadStream;
        createWriteStream(path: import("fs").PathLike, options?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | {
            flags?: string | undefined;
            encoding?: "ascii" | "utf8" | "utf-8" | "utf16le" | "ucs2" | "ucs-2" | "base64" | "base64url" | "latin1" | "binary" | "hex" | undefined;
            fd?: number | undefined;
            mode?: number | undefined;
            autoClose?: boolean | undefined;
            emitClose?: boolean | undefined;
            start?: number | undefined;
            highWaterMark?: number | undefined;
        } | undefined): import("fs").WriteStream;
        fdatasyncSync(fd: number): void;
        copyFileSync(src: import("fs").PathLike, dest: import("fs").PathLike, flags?: number | undefined): void;
        writev: typeof import("fs").writev;
        writevSync(fd: number, buffers: readonly NodeJS.ArrayBufferView[], position?: number | undefined): number;
        readv: typeof import("fs").readv;
        readvSync(fd: number, buffers: readonly NodeJS.ArrayBufferView[], position?: number | undefined): number;
        opendirSync(path: import("fs").PathLike, options?: import("fs").OpenDirOptions | undefined): import("fs").Dir;
        promises: typeof import("fs/promises");
        Stats: typeof import("fs").Stats;
        Dirent: typeof import("fs").Dirent;
        Dir: typeof import("fs").Dir;
        ReadStream: typeof import("fs").ReadStream;
        WriteStream: typeof import("fs").WriteStream;
        BigIntStats: typeof import("fs").BigIntStats;
    };
    protected _logger: Logger;
    get debug(): (...args: any[]) => void;
    get info(): (...args: any[]) => void;
    get log(): (...args: any[]) => void;
    get warn(): (...args: any[]) => void;
    get error(): (...args: any[]) => void;
    constructor(task: Task<O>, global: GlobalOptions);
    /**
     * get task options
     */
    get options(): O;
    /**
     * run a task manually
     * @param task
     * @param options
     */
    run(task: string | Task, options?: RunTaskOptions): Promise<void>;
}
export declare type Callback = {
    fn: (args?: any) => void | Promise<void>;
    namespaces: string[];
};
export declare type ListenerNames = 'before' | 'after' | 'onerror';
export declare class TaskManager {
    private _tasks;
    private _didMap;
    namespaces: string[];
    listeners: {
        before: Callback[];
        after: Callback[];
        onerror: Callback[];
    };
    globalOptions: GlobalOptions;
    getTasks(): Task<any>[];
    addTask(task: Task): Task<any>;
    resolveDependencyTree(t: Task, depth?: number): DepsTree;
    isLoading(t: Task, props: RunTaskOptions): boolean;
    runDepsTree(depsTree: DepsTree, props: RunTaskOptions): Promise<void>;
    runListner(name: ListenerNames, ns: string[], args?: any[]): Promise<void>;
    run(name?: string | Task, props?: RunTaskOptions): Promise<void>;
}
